@@ -1,4 +1,6 @@
+import binascii
 import copy
+import string
 from typing import Any, Dict, Iterable, Iterator, List, Optional, Set, Union, cast
 
 from json_schema_for_humans import const
@@ -9,6 +11,9 @@ from json_schema_for_humans.generation_configuration import GenerationConfigurat
 circular_references: Dict["SchemaNode", bool] = {}
 
 
+ALLOWED_ID_CHARS = string.ascii_letters + string.digits + "_" + "-"
+
+
 class SchemaNode:
     """
     Represents a part of a JSON schema with additional metadata to help with documentation
